@@ -23,9 +23,16 @@ class DependencyProcessor:
     def initialize(self, value):
         return value
 
+    def finalize(self, value):
+        pass
+
 
 class TableDatabaseDependency(DependencyProcessor):
     return_type = WarpzoneDatabaseClient
 
     def initialize(self, value):
-        return integrations.get_db_client()
+        db = integrations.get_db_client()
+        return db
+
+    def finalize(self, db: WarpzoneDatabaseClient):
+        db.clear_cache()
